==> rsplib_2.6.0.orig.tar.gz: rsplib-2.6.0/rsplib/scriptingpackets.h <==
/* $Id: scriptingpackets.h 2076 2008-12-28 15:52:34Z dreibh $
 * --------------------------------------------------------------------------
 *
 *              //===//   //=====   //===//   //       //   //===//
 *             //    //  //        //    //  //       //   //    //
 *            //===//   //=====   //===//   //       //   //===<<
 *           //   \\         //  //        //       //   //    //
 *          //     \\  =====//  //        //=====  //   //===//    Version II
 *
 * ------------- An Efficient RSerPool Prototype Implementation -------------
 *
 * Copyright (C) 2002-2009 by Thomas Dreibholz
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact: dreibh@iem.uni-due.de
 */

#ifndef SCRIPTINGPACKETS_H
#define SCRIPTINGPACKETS_H

#include "tdtypes.h"


#define PPID_SP          0x29097604

#define SPT_READY              0x01
#define SPT_UPLOAD             0x02
#define SPT_DOWNLOAD           0x03
#define SPT_KEEPALIVE          0x04
#define SPT_KEEPALIVE_ACK      0x05
#define SPT_STATUS             0x06

#define SD_MAX_DATASIZE        1400

struct ScriptingCommonHeader
{
   uint8_t  Type;
   uint8_t  Flags;
   uint16_t Length;
} __attribute__((packed));


struct Ready
{
   struct ScriptingCommonHeader Header;
} __attribute__((packed));

struct Upload
{
   struct ScriptingCommonHeader Header;
   char                         Data[SD_MAX_DATASIZE];
} __attribute__((packed));

struct UploadComplete
{
   struct ScriptingCommonHeader Header;
} __attribute__((packed));

struct Download
{
   struct ScriptingCommonHeader Header;
   char                         Data[SD_MAX_DATASIZE];
} __attribute__((packed));

struct DownloadComplete
{
   struct ScriptingCommonHeader Header;
} __attribute__((packed));

struct KeepAlive
{
   struct ScriptingCommonHeader Header;
} __attribute__((packed));

struct KeepAliveAck
{
   struct ScriptingCommonHeader Header;
   uint32_t                     Status;
} __attribute__((packed));

struct Status
{
   struct ScriptingCommonHeader Header;
   uint32_t                     Status;
} __attribute__((packed));

#endif

==> rsplib_2.7.0.orig.tar.gz: rsplib-2.7.0/rsplib/scriptingpackets.h <==
/* $Id: scriptingpackets.h 2240 2009-10-21 08:11:57Z dreibh $
 * --------------------------------------------------------------------------
 *
 *              //===//   //=====   //===//   //       //   //===//
 *             //    //  //        //    //  //       //   //    //
 *            //===//   //=====   //===//   //       //   //===<<
 *           //   \\         //  //        //       //   //    //
 *          //     \\  =====//  //        //=====  //   //===//    Version II
 *
 * ------------- An Efficient RSerPool Prototype Implementation -------------
 *
 * Copyright (C) 2002-2009 by Thomas Dreibholz
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact: dreibh@iem.uni-due.de
 */

#ifndef SCRIPTINGPACKETS_H
#define SCRIPTINGPACKETS_H

#include "tdtypes.h"


#define PPID_SP          0x29097604

#define SPT_NOTREADY           0x00
#define SPT_READY              0x01
#define SPT_UPLOAD             0x02
#define SPT_DOWNLOAD           0x03
#define SPT_KEEPALIVE          0x04
#define SPT_KEEPALIVE_ACK      0x05
#define SPT_STATUS             0x06

#define SD_MAX_DATASIZE        1400
#define SR_MAX_INFOSIZE          64

struct ScriptingCommonHeader
{
   uint8_t  Type;
   uint8_t  Flags;
   uint16_t Length;
} __attribute__((packed));


struct NotReady
{
   struct ScriptingCommonHeader Header;
   uint32_t                     Reason;
   char                         Info[];
} __attribute__((packed));

#define SSNR_FULLY_LOADED     0x0000001
#define SSNR_OUT_OF_RESOURCES 0x00000002


struct Ready
{
   struct ScriptingCommonHeader Header;
   char                         Info[];
} __attribute__((packed));

struct Upload
{
   struct ScriptingCommonHeader Header;
   char                         Data[SD_MAX_DATASIZE];
} __attribute__((packed));

struct Download
{
   struct ScriptingCommonHeader Header;
   char                         Data[SD_MAX_DATASIZE];
} __attribute__((packed));

struct KeepAlive
{
   struct ScriptingCommonHeader Header;
} __attribute__((packed));

struct KeepAliveAck
{
   struct ScriptingCommonHeader Header;
   uint32_t                     Status;
} __attribute__((packed));

struct Status
{
   struct ScriptingCommonHeader Header;
   uint32_t                     Status;
} __attribute__((packed));

#endif
